package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.DxNews;
import com.ruoyi.system.service.IDxNewsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 新闻管理Controller
 * 
 * @author D
 * @date 2025-03-24
 */
@RestController
@RequestMapping("/system/news")
public class DxNewsController extends BaseController
{
    @Autowired
    private IDxNewsService dxNewsService;

    /**
     * 查询新闻管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:news:list')")
    @GetMapping("/list")
    public TableDataInfo list(DxNews dxNews)
    {
        startPage();
        List<DxNews> list = dxNewsService.selectDxNewsList(dxNews);
        return getDataTable(list);
    }

    /**
     * 导出新闻管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:news:export')")
    @Log(title = "新闻管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DxNews dxNews)
    {
        List<DxNews> list = dxNewsService.selectDxNewsList(dxNews);
        ExcelUtil<DxNews> util = new ExcelUtil<DxNews>(DxNews.class);
        util.exportExcel(response, list, "新闻管理数据");
    }

    /**
     * 获取新闻管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:news:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dxNewsService.selectDxNewsById(id));
    }

    /**
     * 新增新闻管理
     */
    @PreAuthorize("@ss.hasPermi('system:news:add')")
    @Log(title = "新闻管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DxNews dxNews)
    {
        return toAjax(dxNewsService.insertDxNews(dxNews));
    }

    /**
     * 修改新闻管理
     */
    @PreAuthorize("@ss.hasPermi('system:news:edit')")
    @Log(title = "新闻管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DxNews dxNews)
    {
        return toAjax(dxNewsService.updateDxNews(dxNews));
    }

    /**
     * 删除新闻管理
     */
    @PreAuthorize("@ss.hasPermi('system:news:remove')")
    @Log(title = "新闻管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dxNewsService.deleteDxNewsByIds(ids));
    }
}
